@@ -1,12 +1,10 @@
-from __future__ import with_statement, unicode_literals
 import os
 import codecs
 from importlib import import_module
+from urllib.request import url2pathname
 
-from django import VERSION
 from django.core.files.base import ContentFile
 from django.utils.safestring import mark_safe
-from django.utils.six.moves.urllib.request import url2pathname
 from django.template.loader import render_to_string
 from django.utils.functional import cached_property
 
@@ -15,7 +13,6 @@ from compressor.conf import settings
 from compressor.exceptions import (CompressorError, UncompressableFileError,
         FilterDoesNotExist)
 from compressor.filters import CachedCompilerFilter
-from compressor.filters.css_default import CssAbsoluteFilter, CssRelativeFilter
 from compressor.storage import compressor_file_storage
 from compressor.signals import post_compress
 from compressor.utils import get_class, get_mod_func, staticfiles
@@ -25,26 +22,45 @@ SOURCE_HUNK, SOURCE_FILE = 'inline', 'file'
 METHOD_INPUT, METHOD_OUTPUT = 'input', 'output'
 
 
-class Compressor(object):
+class Compressor:
     """
     Base compressor object to be subclassed for content type
     depending implementations details.
     """
 
-    def __init__(self, content=None, output_prefix=None,
-                 context=None, filters=None, *args, **kwargs):
+    output_mimetypes = {}
+
+    def __init__(self, resource_kind, content=None, output_prefix=None,
+                 context=None, filters=None, log=None, verbosity=1, *args, **kwargs):
+        if filters is None:
+            self.filters = settings.COMPRESS_FILTERS[resource_kind]
+        else:
+            self.filters = filters
+        if output_prefix is None:
+            self.output_prefix = resource_kind
+        else:
+            self.output_prefix = output_prefix
         self.content = content or ""  # rendered contents of {% compress %} tag
-        self.output_prefix = output_prefix or "compressed"
         self.output_dir = settings.COMPRESS_OUTPUT_DIR.strip('/')
         self.charset = settings.DEFAULT_CHARSET
         self.split_content = []
         self.context = context or {}
-        self.type = output_prefix or ""
-        self.filters = filters or []
+        self.resource_kind = resource_kind
         self.extra_context = {}
         self.precompiler_mimetypes = dict(settings.COMPRESS_PRECOMPILERS)
         self.finders = staticfiles.finders
         self._storage = None
+        self.log = log
+        self.verbosity = verbosity
+
+    def copy(self, **kwargs):
+        keywords = dict(
+            content=self.content,
+            context=self.context,
+            output_prefix=self.output_prefix,
+            filters=self.filters)
+        keywords.update(kwargs)
+        return self.__class__(self.resource_kind, **keywords)
 
     @cached_property
     def storage(self):
@@ -68,7 +84,7 @@ class Compressor(object):
                 return template
         except AttributeError:
             pass
-        return "compressor/%s_%s.html" % (self.type, mode)
+        return "compressor/%s_%s.html" % (self.resource_kind, mode)
 
     def get_basename(self, url):
         """
@@ -79,6 +95,13 @@ class Compressor(object):
             base_url = self.storage.base_url
         except AttributeError:
             base_url = settings.COMPRESS_URL
+
+        # Cast ``base_url`` to a string to allow it to be
+        # a string-alike object to e.g. add ``SCRIPT_NAME``
+        # WSGI param as a *path prefix* to the output URL.
+        # See https://code.djangoproject.com/ticket/25598.
+        base_url = str(base_url)
+
         if not url.startswith(base_url):
             raise UncompressableFileError("'%s' isn't accessible via "
                                           "COMPRESS_URL ('%s') and can't be "
@@ -103,7 +126,7 @@ class Compressor(object):
         if basename:
             filename = os.path.split(basename)[1]
             parts.append(os.path.splitext(filename)[0])
-        parts.extend([get_hexdigest(content, 12), self.type])
+        parts.extend([get_hexdigest(content, 12), self.resource_kind])
         return os.path.join(self.output_dir, self.output_prefix, '.'.join(parts))
 
     def get_filename(self, basename):
@@ -120,15 +143,24 @@ class Compressor(object):
             try:
                 # call path first so remote storages don't make it to exists,
                 # which would cause network I/O
+                if self.log and self.verbosity >= 2:
+                    self.log.write('Looking for \'{}\' in storage\n'.format(basename))
                 filename = self.storage.path(basename)
                 if not self.storage.exists(basename):
                     filename = None
             except NotImplementedError:
                 # remote storages don't implement path, access the file locally
+                if self.log and self.verbosity >= 2:
+                    self.log.write('Remote storages don\'t implement path, looking for the file locally\n')
                 if compressor_file_storage.exists(basename):
                     filename = compressor_file_storage.path(basename)
         # secondly try to find it with staticfiles
         if not filename and self.finders:
+            if self.log and self.verbosity >= 2:
+                if not settings.DEBUG:
+                    self.log.write('\'{}\' was not found in storage, using static finders\n'.format(basename))
+                else:
+                    self.log.write('Using static finders for \'{}\'\n'.format(basename))
             filename = self.finders.find(url2pathname(basename))
         if filename:
             return filename
@@ -207,13 +239,9 @@ class Compressor(object):
             if enabled:
                 yield self.filter(value, self.cached_filters, **options)
             elif precompiled:
-                # since precompiling moves files around, it breaks url()
-                # statements in css files. therefore we run the absolute filter
-                # on precompiled css files even if compression is disabled.
-                if CssAbsoluteFilter in self.cached_filters:
-                    value = self.filter(value, [CssAbsoluteFilter], **options)
-                elif CssRelativeFilter in self.cached_filters:
-                    value = self.filter(value, [CssRelativeFilter], **options)
+                for filter_cls in self.cached_filters:
+                    if filter_cls.run_with_compression_disabled:
+                        value = self.filter(value, [filter_cls], **options)
                 yield self.handle_output(kind, value, forced=True,
                                          basename=basename)
             else:
@@ -252,7 +280,7 @@ class Compressor(object):
 
         filter_or_command = self.precompiler_mimetypes.get(mimetype)
         if filter_or_command is None:
-            if mimetype in ("text/css", "text/javascript"):
+            if mimetype in self.output_mimetypes:
                 return False, content
             raise CompressorError("Couldn't find any precompiler in "
                                   "COMPRESS_PRECOMPILERS setting for "
@@ -263,7 +291,7 @@ class Compressor(object):
             mod = import_module(mod_name)
         except (ImportError, TypeError):
             filter = CachedCompilerFilter(
-                content=content, filter_type=self.type, filename=filename,
+                content=content, filter_type=self.resource_kind, filename=filename,
                 charset=charset, command=filter_or_command, mimetype=mimetype)
             return True, filter.input(**kwargs)
         try:
@@ -271,14 +299,14 @@ class Compressor(object):
         except AttributeError:
             raise FilterDoesNotExist('Could not find "%s".' % filter_or_command)
         filter = precompiler_class(
-            content, attrs=attrs, filter_type=self.type, charset=charset,
+            content, attrs=attrs, filter_type=self.resource_kind, charset=charset,
             filename=filename)
         return True, filter.input(**kwargs)
 
     def filter(self, content, filters, method, **kwargs):
         for filter_cls in filters:
             filter_func = getattr(
-                filter_cls(content, filter_type=self.type), method)
+                filter_cls(content, filter_type=self.resource_kind), method)
             try:
                 if callable(filter_func):
                     content = filter_func(**kwargs)
@@ -286,7 +314,7 @@ class Compressor(object):
                 pass
         return content
 
-    def output(self, mode='file', forced=False):
+    def output(self, mode='file', forced=False, basename=None):
         """
         The general output method, override in subclass if you need to do
         any custom modification. Calls other mode specific methods or simply
@@ -299,7 +327,7 @@ class Compressor(object):
 
         if settings.COMPRESS_ENABLED or forced:
             filtered_output = self.filter_output(output)
-            return self.handle_output(mode, filtered_output, forced)
+            return self.handle_output(mode, filtered_output, forced, basename)
 
         return output
 
@@ -330,6 +358,13 @@ class Compressor(object):
         """
         return self.render_output(mode, {"content": content})
 
+    def output_preload(self, mode, content, forced=False, basename=None):
+        """
+        The output method that returns <link> with rel="preload" and
+        proper href attribute for given file.
+        """
+        return self.output_file(mode, content, forced, basename)
+
     def render_output(self, mode, context=None):
         """
         Renders the compressor output with the appropriate template for
@@ -343,15 +378,13 @@ class Compressor(object):
         self.context['compressed'].update(context or {})
         self.context['compressed'].update(self.extra_context)
 
-        if hasattr(self.context, 'flatten') and VERSION >= (1, 9):
+        if hasattr(self.context, 'flatten'):
             # Passing Contexts to Template.render is deprecated since Django 1.8.
-            # However, we use the fix below only for django 1.9 and above, since
-            # the flatten method is buggy in 1.8, see https://code.djangoproject.com/ticket/24765
             final_context = self.context.flatten()
         else:
             final_context = self.context
 
-        post_compress.send(sender=self.__class__, type=self.type,
+        post_compress.send(sender=self.__class__, type=self.resource_kind,
                            mode=mode, context=final_context)
         template_name = self.get_template_name(mode)
         return render_to_string(template_name, context=final_context)
