@@ -1,4 +1,3 @@
-from __future__ import unicode_literals
 import os
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
@@ -19,16 +18,24 @@ class CompressorConf(AppConf):
     OUTPUT_DIR = 'CACHE'
     STORAGE = 'compressor.storage.CompressorFileStorage'
 
-    CSS_COMPRESSOR = 'compressor.css.CssCompressor'
-    JS_COMPRESSOR = 'compressor.js.JsCompressor'
+    COMPRESSORS = dict(
+        css='compressor.css.CssCompressor',
+        js='compressor.js.JsCompressor',
+    )
 
     URL = None
     ROOT = None
 
-    CSS_FILTERS = ['compressor.filters.css_default.CssAbsoluteFilter']
+    FILTERS = {
+        'css': [
+            'compressor.filters.css_default.CssAbsoluteFilter',
+            'compressor.filters.cssmin.rCSSMinFilter'
+        ],
+        'js': ['compressor.filters.jsmin.rJSMinFilter']
+    }
+
     CSS_HASHING_METHOD = 'mtime'
 
-    JS_FILTERS = ['compressor.filters.jsmin.JSMinFilter']
     PRECOMPILERS = (
         # ('text/coffeescript', 'coffee --compile --stdio'),
         # ('text/less', 'lessc {infile} {outfile}'),
@@ -97,8 +104,8 @@ class CompressorConf(AppConf):
         if value is None:
             value = settings.STATIC_ROOT
         if value is None:
-            raise ImproperlyConfigured('COMPRESS_ROOT defaults to ' +
-                                       'STATIC_ROOT, please define either')
+            raise ImproperlyConfigured('COMPRESS_ROOT defaults to '
+                                       + 'STATIC_ROOT, please define either')
         return os.path.normcase(os.path.abspath(value))
 
     def configure_url(self, value):
