@@ -38,3 +38,17 @@ class FilterDoesNotExist(Exception):
     Raised when a filter class cannot be found.
     """
     pass
+
+
+class TemplateDoesNotExist(Exception):
+    """
+    This exception is raised when a template does not exist.
+    """
+    pass
+
+
+class TemplateSyntaxError(Exception):
+    """
+    This exception is raised when a template syntax error is encountered.
+    """
+    pass
