@@ -6,7 +6,7 @@ class YUICompressorFilter(CompilerFilter):
     command = "{binary} {args}"
 
     def __init__(self, *args, **kwargs):
-        super(YUICompressorFilter, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.command += ' --type=%s' % self.type
         if self.verbose:
             self.command += ' --verbose'
