@@ -1,22 +1,21 @@
-import sys
+import html.parser
 
-from django.utils import six
-from django.utils.encoding import smart_text
+from django.utils.encoding import smart_str
 
 from compressor.exceptions import ParserError
 from compressor.parser import ParserBase
 
 
-# Since Python 3.4, the HTMLParser constructor takes a 'convert_charrefs'
+# The HTMLParser constructor takes a 'convert_charrefs'
 # argument which raises a warning if we don't pass it.
-HTML_PARSER_ARGS = {}
-if sys.version_info[:2] >= (3, 4):
-    HTML_PARSER_ARGS['convert_charrefs'] = False
+HTML_PARSER_ARGS = {
+    'convert_charrefs': False,
+}
 
 
-class DefaultHtmlParser(ParserBase, six.moves.html_parser.HTMLParser):
+class DefaultHtmlParser(ParserBase, html.parser.HTMLParser):
     def __init__(self, content):
-        six.moves.html_parser.HTMLParser.__init__(self, **HTML_PARSER_ARGS)
+        html.parser.HTMLParser.__init__(self, **HTML_PARSER_ARGS)
         self.content = content
         self._css_elems = []
         self._js_elems = []
@@ -74,7 +73,7 @@ class DefaultHtmlParser(ParserBase, six.moves.html_parser.HTMLParser):
         return elem['attrs_dict']
 
     def elem_content(self, elem):
-        return smart_text(elem['text'])
+        return smart_str(elem['text'])
 
     def elem_str(self, elem):
         tag = {}
@@ -83,6 +82,6 @@ class DefaultHtmlParser(ParserBase, six.moves.html_parser.HTMLParser):
         if len(elem['attrs']):
             tag['attrs'] = ' %s' % ' '.join(['%s="%s"' % (name, value) for name, value in elem['attrs']])
         if elem['tag'] == 'link':
-            return '<%(tag)s%(attrs)s />' % tag
+            return '<%(tag)s%(attrs)s>' % tag
         else:
             return '<%(tag)s%(attrs)s>%(text)s</%(tag)s>' % tag
