@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-import errno
 import gzip
 import os
 from datetime import datetime
@@ -24,8 +22,7 @@ class CompressorFileStorage(FileSystemStorage):
             location = settings.COMPRESS_ROOT
         if base_url is None:
             base_url = settings.COMPRESS_URL
-        super(CompressorFileStorage, self).__init__(location, base_url,
-                                                    *args, **kwargs)
+        super().__init__(location, base_url, *args, **kwargs)
 
     def accessed_time(self, name):
         return datetime.fromtimestamp(os.path.getatime(self.path(name)))
@@ -36,24 +33,16 @@ class CompressorFileStorage(FileSystemStorage):
     def modified_time(self, name):
         return datetime.fromtimestamp(os.path.getmtime(self.path(name)))
 
-    def get_available_name(self, name, max_length=None):
-        """
-        Deletes the given file if it exists.
-        """
-        if self.exists(name):
-            self.delete(name)
-        return name
+    def save(self, filename, content):
+        temp_filename = super().save(filename, content)
+        # If a file already exists  in the target location, FileSystemStorage
+        # will generate an unique filename and save content there instead.
+        # When that happens, we move the file to the intended location using
+        # os.replace() (which is an atomic operation):
+        if temp_filename != filename:
+            os.replace(self.path(temp_filename), self.path(filename))
 
-    def delete(self, name):
-        """
-        Handle deletion race condition present in Django prior to 1.4
-        https://code.djangoproject.com/ticket/16108
-        """
-        try:
-            super(CompressorFileStorage, self).delete(name)
-        except OSError as e:
-            if e.errno != errno.ENOENT:
-                raise
+        return filename
 
 
 compressor_file_storage = SimpleLazyObject(
@@ -62,16 +51,15 @@ compressor_file_storage = SimpleLazyObject(
 
 class GzipCompressorFileStorage(CompressorFileStorage):
     """
-    The standard compressor file system storage that gzips storage files
-    additionally to the usual files.
+    File system storage that stores gzipped files in addition to the usual files.
     """
     def save(self, filename, content):
-        filename = super(GzipCompressorFileStorage, self).save(filename, content)
+        filename = super().save(filename, content)
         orig_path = self.path(filename)
         compressed_path = '%s.gz' % orig_path
 
         with open(orig_path, 'rb') as f_in, open(compressed_path, 'wb') as f_out:
-            with gzip.GzipFile(fileobj=f_out) as gz_out:
+            with gzip.GzipFile(fileobj=f_out, mode='wb') as gz_out:
                 gz_out.write(f_in.read())
 
         # Ensure the file timestamps match.
@@ -85,8 +73,40 @@ class GzipCompressorFileStorage(CompressorFileStorage):
         return filename
 
 
+class BrotliCompressorFileStorage(CompressorFileStorage):
+    """
+    File system storage that stores brotli files in addition to the usual files.
+    """
+    chunk_size = 1024
+
+    def save(self, filename, content):
+        filename = super().save(filename, content)
+        orig_path = self.path(filename)
+        compressed_path = '%s.br' % orig_path
+
+        import brotli
+        br_compressor = brotli.Compressor()
+        with open(orig_path, 'rb') as f_in, open(compressed_path, 'wb') as f_out:
+            for f_in_data in iter(lambda: f_in.read(self.chunk_size), b''):
+                compressed_data = br_compressor.process(f_in_data)
+                if not compressed_data:
+                    compressed_data = br_compressor.flush()
+                f_out.write(compressed_data)
+            f_out.write(br_compressor.finish())
+        # Ensure the file timestamps match.
+        # os.stat() returns nanosecond resolution on Linux, but os.utime()
+        # only sets microsecond resolution.  Set times on both files to
+        # ensure they are equal.
+        stamp = time.time()
+        os.utime(orig_path, (stamp, stamp))
+        os.utime(compressed_path, (stamp, stamp))
+
+        return filename
+
+
 class DefaultStorage(LazyObject):
     def _setup(self):
         self._wrapped = get_storage_class(settings.COMPRESS_STORAGE)()
 
+
 default_storage = DefaultStorage()
