@@ -1,7 +1,6 @@
-from django.test import TestCase
-from django.test.utils import override_settings
+from unittest.mock import Mock
 
-from mock import Mock
+from django.test import override_settings, TestCase
 
 from compressor.css import CssCompressor
 from compressor.js import JsCompressor
