@@ -1,20 +1,15 @@
-from __future__ import with_statement, unicode_literals
-
 import os
 import sys
+from unittest.mock import Mock
 
-from mock import Mock
+from django.conf import settings
+from django.template import Context, Template, TemplateSyntaxError
+from django.test import override_settings, TestCase
+from sekizai.context import SekizaiContext
 
-from django.template import Template, Context, TemplateSyntaxError
-from django.test import TestCase
-from django.test.utils import override_settings
-
-from compressor.conf import settings
 from compressor.signals import post_compress
 from compressor.tests.test_base import css_tag, test_dir
 
-from sekizai.context import SekizaiContext
-
 
 def render(template_string, context_dict=None, context=None):
     """
@@ -45,7 +40,7 @@ class TemplatetagTestCase(TestCase):
 <style type="text/css">p { border:5px solid green;}</style>
 <link rel="stylesheet" href="{{ STATIC_URL }}css/two.css" type="text/css">
 {% endcompress %}"""
-        out = css_tag("/static/CACHE/css/output.58a8c0714e59.css")
+        out = css_tag("/static/CACHE/css/output.600674ea1d3d.css")
         self.assertEqual(out, render(template, self.context))
 
     def test_css_tag_with_block(self):
@@ -54,7 +49,7 @@ class TemplatetagTestCase(TestCase):
 <style type="text/css">p { border:5px solid blue;}</style>
 <link rel="stylesheet" href="{{ STATIC_URL }}css/two.css" type="text/css">
 {% endcompress %}"""
-        out = css_tag("/static/CACHE/css/block_name.393dbcddb48e.css")
+        out = css_tag("/static/CACHE/css/block_name.a1e074d0c4ac.css")
         self.assertEqual(out, render(template, self.context))
 
     def test_missing_rel_leaves_empty_result(self):
@@ -71,7 +66,7 @@ class TemplatetagTestCase(TestCase):
 <style type="text/css">p { border:5px solid green;}</style>
 <link rel="stylesheet" href="{{ STATIC_URL }}css/two.css" type="text/css">
 {% endcompress %}"""
-        out = css_tag("/static/CACHE/css/output.58a8c0714e59.css")
+        out = css_tag("/static/CACHE/css/output.600674ea1d3d.css")
         self.assertEqual(out, render(template, self.context))
 
     def test_uppercase_rel(self):
@@ -80,7 +75,7 @@ class TemplatetagTestCase(TestCase):
 <style type="text/css">p { border:5px solid green;}</style>
 <link rel="StyleSheet" href="{{ STATIC_URL }}css/two.css" type="text/css">
 {% endcompress %}"""
-        out = css_tag("/static/CACHE/css/output.58a8c0714e59.css")
+        out = css_tag("/static/CACHE/css/output.600674ea1d3d.css")
         self.assertEqual(out, render(template, self.context))
 
     def test_nonascii_css_tag(self):
@@ -89,7 +84,7 @@ class TemplatetagTestCase(TestCase):
         <style type="text/css">p { border:5px solid green;}</style>
         {% endcompress %}
         """
-        out = css_tag("/static/CACHE/css/output.4263023f49d6.css")
+        out = css_tag("/static/CACHE/css/output.d5444a1ab4a3.css")
         self.assertEqual(out, render(template, self.context))
 
     def test_js_tag(self):
@@ -133,7 +128,7 @@ class TemplatetagTestCase(TestCase):
         {% endcompress %}
         """
 
-        class MockDebugRequest(object):
+        class MockDebugRequest:
             GET = {settings.COMPRESS_DEBUG_TOGGLE: 'true'}
 
         context = dict(self.context, request=MockDebugRequest())
@@ -150,11 +145,10 @@ class TemplatetagTestCase(TestCase):
         <style type="text/css">p { border:5px solid green;}</style>
         <link rel="stylesheet" href="{{ STATIC_URL }}css/two.css" type="text/css">
         {% endcompress %}"""
-
         out_js = '<script>obj={};;obj.value="value";;</script>'
-        out_css = '\n'.join(('<style type="text/css">body { background:#990; }',
-                             'p { border:5px solid green;}',
-                             'body { color:#fff; }</style>'))
+        out_css = ('<style type="text/css">body{background:#990}'
+                   'p{border:5px solid green}'
+                   'body{color:#fff}</style>')
         self.assertEqual(out_js + out_css, render(template, self.context))
 
     def test_named_compress_tag(self):
